<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AppMain</name>
    <message>
        <location filename="src/common/vlcpalyer.cpp" line="54"/>
        <location filename="src/main.cpp" line="94"/>
        <location filename="src/main.cpp" line="95"/>
        <location filename="src/views/vnotemainwindow.cpp" line="615"/>
        <source>Voice Notes</source>
        <translation>Notes de veu</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="96"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation>Les Notes de veu és una eina lleugera per fer notes de text i gravacions de veu.</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="616"/>
        <source>Recordings not saved</source>
        <translation>Gravacions no desades</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="src/db/vnotefolderoper.cpp" line="245"/>
        <source>Notebook</source>
        <translation>Quadern</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="228"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="src/db/vnoteitemoper.cpp" line="243"/>
        <location filename="src/importolddata/olddbvisistors.cpp" line="154"/>
        <source>Voice</source>
        <translation>Veu</translation>
    </message>
</context>
<context>
    <name>DetailPage</name>
    <message>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
        <source>%1 notes selected</source>
        <translation>%1 notes seleccionades</translation>
    </message>
</context>
<context>
    <name>FolderSelectDialog</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="217"/>
        <source>Move Notes</source>
        <translation>Mou les notes</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="244"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="245"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="src/views/homepage.cpp" line="48"/>
        <source>Create Notebook</source>
        <translation>Crea un quadern</translation>
    </message>
    <message>
        <location filename="src/views/homepage.cpp" line="60"/>
        <source>Create a notebook to start recording voice and making notes</source>
        <translation>Creeu un quadern per començar a gravar notes de veu i de text.</translation>
    </message>
</context>
<context>
    <name>LeftView</name>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="380"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="394"/>
        <source>Move %1 notes (%2, ...) to:</source>
        <translation>Mou %1 notes (%2...) a</translation>
    </message>
    <message>
        <location filename="src/dialog/folderselectdialog.cpp" line="381"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="384"/>
        <location filename="src/dialog/folderselectdialog.cpp" line="392"/>
        <source>Move the note &quot;%1&quot; to:</source>
        <translation>Mou la nota %1 a</translation>
    </message>
</context>
<context>
    <name>MiddleView</name>
    <message>
        <location filename="src/views/middleview.cpp" line="303"/>
        <source>Save</source>
        <translation>Desa-ho</translation>
    </message>
    <message>
        <location filename="src/views/middleview.cpp" line="1057"/>
        <source>No search results</source>
        <translation>No hi ha cap resultat de la cerca.</translation>
    </message>
</context>
<context>
    <name>MiddleViewDelegate</name>
    <message>
        <location filename="src/views/middleviewdelegate.cpp" line="442"/>
        <source>Sticky Notes</source>
        <translation>Notes adhesives</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="276"/>
        <source>Save as MP3</source>
        <translation>Desa-ho com a MP3</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="277"/>
        <source>Voice to Text</source>
        <translation>De veu a text</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="278"/>
        <location filename="src/common/actionmanager.cpp" line="305"/>
        <location filename="src/common/actionmanager.cpp" line="331"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="279"/>
        <location filename="src/common/actionmanager.cpp" line="306"/>
        <location filename="src/common/actionmanager.cpp" line="332"/>
        <source>Select all</source>
        <translation>Selecciona-ho tot</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="280"/>
        <location filename="src/common/actionmanager.cpp" line="307"/>
        <location filename="src/common/actionmanager.cpp" line="333"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="281"/>
        <location filename="src/common/actionmanager.cpp" line="308"/>
        <location filename="src/common/actionmanager.cpp" line="334"/>
        <source>Cut</source>
        <translation>Retalla</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="282"/>
        <location filename="src/common/actionmanager.cpp" line="309"/>
        <location filename="src/common/actionmanager.cpp" line="335"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="304"/>
        <source>View</source>
        <translation>Visualització</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="310"/>
        <source>Save as</source>
        <translation>Desa-ho com a</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="336"/>
        <source>Text to Speech</source>
        <translation>De text a veu</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="337"/>
        <source>Stop reading</source>
        <translation>Interromp la lectura</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="338"/>
        <source>Speech to Text</source>
        <translation>De veu a text</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="339"/>
        <source>Translate</source>
        <translation>Tradueix</translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="220"/>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="221"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="222"/>
        <source>New note</source>
        <translation>Nota nova</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="src/common/actionmanager.cpp" line="195"/>
        <source>Save as HTML</source>
        <translation>Desa-ho com a HTML</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="196"/>
        <source>Save as TXT</source>
        <translation>Desa-ho com a TXT</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="200"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
        <source>Save note</source>
        <translation>Desa la nota</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="240"/>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="242"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
        <source>Move</source>
        <translation>Mou</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="243"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="245"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
        <source>Save voice recording</source>
        <translation>Desa la gravació de veu</translation>
    </message>
    <message>
        <location filename="src/common/actionmanager.cpp" line="246"/>
        <source>New note</source>
        <translation>Nota nova</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1258"/>
        <source>Unstick</source>
        <translation>Desenganxa</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1260"/>
        <source>Sticky on Top</source>
        <translation>Les adhesives a dalt</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="src/common/setting.cpp" line="39"/>
        <source>Basic</source>
        <translation>Bàsic</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="40"/>
        <source>Audio Source</source>
        <translation>Font d&apos;àudio</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="41"/>
        <source>Internal</source>
        <translation>Intern</translation>
    </message>
    <message>
        <location filename="src/common/setting.cpp" line="42"/>
        <source>Microphone</source>
        <translation>Micròfon</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="919"/>
        <source>New notebook</source>
        <translation>Quadern nou</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="920"/>
        <source>Rename notebook</source>
        <translation>Canvia el nom del quadern</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="921"/>
        <source>Delete notebook</source>
        <translation>Elimina el quadern</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="943"/>
        <source>New note</source>
        <translation>Nota nova</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="944"/>
        <source>Rename note</source>
        <translation>Canvia el nom de la nota</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="945"/>
        <source>Delete note</source>
        <translation>Elimina la nota</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="946"/>
        <source>Play/Pause</source>
        <translation>Reprodueix / Pausa</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="947"/>
        <source>Record voice</source>
        <translation>Gravació de veu</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="948"/>
        <source>Save note</source>
        <translation>Desa la nota</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="949"/>
        <source>Save recordings</source>
        <translation>Desa les gravacions</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="969"/>
        <source>Select all</source>
        <translation>Selecciona-ho tot</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="970"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="971"/>
        <source>Cut</source>
        <translation>Retalla</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="972"/>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="973"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="996"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="997"/>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="925"/>
        <source>Notebooks</source>
        <translation>Quaderns</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="953"/>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="977"/>
        <source>Edit</source>
        <translation>Edita-ho</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1001"/>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
</context>
<context>
    <name>SplashView</name>
    <message>
        <location filename="src/views/splashview.cpp" line="46"/>
        <source>Loading...</source>
        <translation>Es carrega...</translation>
    </message>
</context>
<context>
    <name>TitleBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="371"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1889"/>
        <source>Settings</source>
        <translation>Paràmetres</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1890"/>
        <source>Privacy Policy</source>
        <translation>Política de privadesa</translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="src/importolddata/upgradeview.cpp" line="50"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>S&apos;importen les notes de la versió antiga. Espereu, si us plau...</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="src/common/utils.cpp" line="56"/>
        <source>1 min ago</source>
        <translation>fa 1 minut</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="58"/>
        <source>%1 mins ago</source>
        <translation>fa %1 minuts</translation>
    </message>
    <message>
        <location filename="src/common/utils.cpp" line="64"/>
        <source>Yesterday</source>
        <translation>ahir</translation>
    </message>
</context>
<context>
    <name>VNoteErrorMessage</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="881"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation>La conversió de veu ha fallat a causa de la mala connexió de xarxa. Comproveu-la, si us plau.</translation>
    </message>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="885"/>
        <source>Voice to text conversion failed</source>
        <translation>Ha fallat la conversió de veu a text.</translation>
    </message>
</context>
<context>
    <name>VNoteMainWindow</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="470"/>
        <source>Create Notebook</source>
        <translation>Crea un quadern</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="53"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="132"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="133"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="136"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation>Segur que voleu eliminar aquest quadern?
Se n&apos;eliminaran totes les notes.</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="139"/>
        <source>Do you want to stop the current recording?</source>
        <translation>Voleu interrompre la gravació actual?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="143"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation>Segur que voleu eliminar les %1 notes seleccionades?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="145"/>
        <source>Are you sure you want to delete this note?</source>
        <translation>Segur que voleu eliminar aquesta nota?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="149"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation>No es pot convertir aquesta nota de veu. Actualment no s&apos;admeten les notes de més de 20 minuts.</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="153"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation>Ara es converteix una nota de veu. Ho voleu interrompre?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="156"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation>Un volum baix d&apos;entrada pot tenir com a resultat una mala gravació. Voleu continuar?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="159"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation>Les gravacions truncades i el text convertit no s&apos;enganxaran. Voleu continuar?</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="162"/>
        <source>Save failed</source>
        <translation>Ha fallat desar-ho.</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="166"/>
        <source>You do not have permission to save files there</source>
        <translation>No teniu permís per desar fitxers aquí.</translation>
    </message>
    <message>
        <location filename="src/dialog/vnotemessagedialog.cpp" line="170"/>
        <source>The voice note has been deleted</source>
        <translation>S&apos;ha eliminat la nota de veu.</translation>
    </message>
</context>
<context>
    <name>VNoteRecordBar</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1736"/>
        <source>Your audio recording device does not work.</source>
        <translation>El dispositiu de gravació d&apos;àudio no funciona.</translation>
    </message>
    <message>
        <location filename="src/views/vnoterecordbar.cpp" line="249"/>
        <source>No recording device detected</source>
        <translation>No s&apos;ha detectat cap dispositiu de gravació.</translation>
    </message>
</context>
<context>
    <name>VoiceNoteItem</name>
    <message>
        <location filename="src/views/vnotemainwindow.cpp" line="1679"/>
        <source>Converting voice to text</source>
        <translation>Es converteix de veu a text</translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="src/common/jscontent.cpp" line="141"/>
        <source>Font</source>
        <translation>Lletra</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="142"/>
        <source>Font size</source>
        <translation>Mida de la lletra</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="143"/>
        <source>Font color</source>
        <translation>Color de la lletra</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="144"/>
        <source>Text highlight color</source>
        <translation>Color del text ressaltat</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="145"/>
        <source>Bold</source>
        <translation>Negreta</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="146"/>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="147"/>
        <source>Underline</source>
        <translation>Subratllat</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="148"/>
        <source>Strikethrough</source>
        <translation>Ratllat</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="149"/>
        <source>Bullets</source>
        <translation>Marques</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="150"/>
        <source>Numbering</source>
        <translation>Numeració</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="151"/>
        <source>More colors</source>
        <translation>Més colors</translation>
    </message>
    <message>
        <location filename="src/common/jscontent.cpp" line="152"/>
        <source>Recent</source>
        <translation>Recent</translation>
    </message>
</context>
</TS>